@@ -1,14 +1,19 @@
 const Interpreter = require('../interpreter/Interpreter')
 const CommandSerializer = require("../protocol/CommandSerializer");
 const InMemoryConnectionData = require("../../utils/connectionData/InMemoryConnectionData");
-const interpreter = new Interpreter()
+const RuntimeLogger = require("../../utils/RuntimeLogger");
+
+
 
 class Receiver {
 
     static connectionData = new InMemoryConnectionData();
+    Receiver() {
+        RuntimeLogger.printRuntimeInfo()
+    }
 
     static sendCommand(messageByteArray) {
-        return new CommandSerializer().serialize(interpreter.process(messageByteArray), this.connectionData)
+        return new CommandSerializer().serialize(new Interpreter().process(messageByteArray), this.connectionData)
     }
     static heartBeat(messageByteArray) {
         let response = new Int8Array(2)
