@@ -1,11 +1,16 @@
+import sys
+
 from javonet.core.interpreter.Interpreter import Interpreter
 from javonet.core.protocol.CommandSerializer import CommandSerializer
+from javonet.utils.RuntimeLogger import RuntimeLogger
 from javonet.utils.connectionData.InMemoryConnectionData import InMemoryConnectionData
 
 
 class Receiver:
 
     def __init__(self):
+        RuntimeLogger.print_runtime_info()
+        sys.stdout.flush()
         self.connection_data = InMemoryConnectionData()
 
     def SendCommand(self, message_byte_array, messageByteArrayLen):
